Documentation
¶
Overview ¶
Package pidfile provides helper functions to create and remove PID files. A PID file is usually a file used to store the process ID of a running process.
This is a temporary copy of github.com/moby/moby/v2/pkg/pidfile, and should be replaced once pidfile is available as a standalone module.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Read ¶
Read reads the "PID file" at path, and returns the PID if it contains a valid PID of a running process, or 0 otherwise. It returns an error when failing to read the file, or if the file doesn't exist, but malformed content is ignored. Consumers should therefore check if the returned PID is a non-zero value before use.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.